Module collections

Module collections 

Structs

DefaultHashBuilder
The default hash builder used by the arena-backed hash collections. Default hash builder for the S type parameter of HashMap and HashSet.

Type Aliases

HashMap
A hash map whose entries live in an arena.
HashSet
A hash set whose elements live in an arena. See HashMap for construction.
HashTable
A low-level hash table whose entries live in an arena. See HashMap for construction.