Module copy

Module copy 

Traits

CopyInto
A deep copy of a value into an arena, rebinding every internal reference.

Functions

copy_ref_into
Copies value into the arena and returns a reference to the copy.
copy_slice_into
Copies every element of values into the arena as a new slice.