pub struct LocalArena<A: Allocator = Global>(/* private fields */);Expand description
A single-threaded bump arena.
Fastest of the three; Send but not Sync. Use it for per-task scratch and
any single-threaded pass.
Implementations
Sourceimpl LocalArena<Global>
impl LocalArena<Global>
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates new arena allocator that uses global allocator to allocate memory chunks.
See LocalArena::new_in for using custom allocator.
Sourcepub const fn with_chunk_size(chunk_size: usize) -> Self
pub const fn with_chunk_size(chunk_size: usize) -> Self
Creates new arena allocator that uses global allocator to allocate memory chunks. With this method you can specify initial chunk size.
See LocalArena::new_in for using custom allocator.
Sourceimpl<A: Allocator> LocalArena<A>
impl<A: Allocator> LocalArena<A>
Sourcepub const fn new_in(arena: A) -> Self
pub const fn new_in(arena: A) -> Self
Creates a new arena that uses arena to allocate its memory chunks.
Sourcepub const fn with_chunk_size_in(chunk_size: usize, arena: A) -> Self
pub const fn with_chunk_size_in(chunk_size: usize, arena: A) -> Self
Creates a new, empty arena whose chunks are at least chunk_size bytes.